@@ -18,14 +18,14 @@
 //!         .default("5.12.0-aosc-main")
 //!         .timeout(5u32)
 //!         .build())
-//!     .entries(vec![EntryBuilder::new("5.12.0-aosc-main")
+//!     .entry(EntryBuilder::new("5.12.0-aosc-main")
 //!         .title("AOSC OS x86_64 (5.12.0-aosc-main)")
 //!         .version("5.12.0-aosc-main")
-//!         .build()])
+//!         .build())
 //!     .build();
 //!
 //! // Or
-//! use libsdbootconf::{Config, Entry, SystemdBootConf, entry::Token};
+//! use libsdbootconf::{Config, Entry, SystemdBootConf, Token};
 //!
 //! let systemd_boot_conf = SystemdBootConf::new(
 //!     "/efi/loader",
@@ -122,12 +122,12 @@ impl SystemdBootConf {
     where
         P: Into<PathBuf>,
         C: Into<Config>,
-        E: IntoIterator<Item = Entry>,
+        E: Into<Vec<Entry>>, 
     {
         Self {
             working_dir: working_dir.into(),
             config: config.into(),
-            entries: entries.into_iter().collect(),
+            entries: entries.into(),
         }
     }
 
@@ -241,9 +241,16 @@ impl SystemdBootConfBuilder {
     );
     generate_builder_method!(
         /// Add a list of `Entry`.
-        intoiter INNER(systemd_boot_conf) entries(E: Entry)
+        into INNER(systemd_boot_conf) entries(E: Vec<Entry>)
     );
 
+    /// Add an `Entry`
+    pub fn entry(mut self, entry: Entry) -> Self {
+        self.systemd_boot_conf.entries.push(entry);
+
+        self
+    }
+
     /// Build the `SystemdBootConf`.
     pub fn build(self) -> SystemdBootConf {
         self.systemd_boot_conf
